@@ -6,13 +6,13 @@ from bits_aviso_python_sdk.services.google.storage import Storage
 def test():
     """Tests the Pubsub class."""
     logger = initialize_logger()
-    #os.environ["GOOGLE_APPLICATION_CREDENTIALS"] = os.environ.get("ARCHIVE_ACCESSOR")
+    os.environ["GOOGLE_APPLICATION_CREDENTIALS"] = os.environ.get("ARCHIVE_ACCESSOR")
 
-    s = Storage(project_id='')
-    bucket = s.list_buckets()[0]
-    size = s.get_bucket_size(bucket.name)
+    s = Storage(project_id='broad-archive')
+    bucket = 'broad-archive-sctask0055808'
+    size = s.get_bucket_size(bucket)
 
-    print(bucket.name, size)
+    print(bucket, size)
 
 
 if __name__ == '__main__':
